import QtQuick 1.1
import com.nokia.meego 1.0
//import com.nokia.extras 1.0

WAStackWindow {
    id: appWindow
    initialPage: mainPage
    showStatusBar: true
    toolBarPlatformStyle:ToolBarStyle{
        inverted: stealth || theme.inverted
    }

    property bool stealth:false

    Component.onCompleted: {
        theme.inverted = true
    }

    platformStyle: defaultStyle

    onStealthMode: {
        console.log("Stealth Mode!")
        theme.inverted = false
        stealth = true;
       // theme.inverted = true
        platformStyle = stealthStyle
    }
    onNormalMode: {
        console.log("Normal Mode!")
        stealth = false
         //theme.inverted = false
        platformStyle=defaultStyle
    }
    function isStealth(){
        return stealth;
    }

    PageStackWindowStyle { id: defaultStyle }
    PageStackWindowStyle {
           id: stealthStyle;
           backgroundColor: "black"
       }



    /*InfoBanner {
        id:osd_notify
       // iconSource: "system_banner_thumbnail.png"
    }*/



    /****** Signal and Slot definitions *******/
    signal sendMessage(string user_id, string msg);
    signal sendRegRequest(string number, string cc);
    signal requestPresence(string user_id);
    signal refreshContacts();
    signal sendTyping(string user_id);
    signal sendPaused(string user_id);
    signal stealthMode()
    signal normalMode()
    signal quit()

            /******************/
    function onConnected(){setIndicatorState("online")}
    function onConnecting(){setIndicatorState("connecting")}
    function onDisconnected(){setIndicatorState("connecting")}
    function onSleeping(){setIndicatorState("offline")}
    function onLoginFailed(){setIndicatorState("reregister")}

    function quitInit(){
        quitConfirm.open();
    }

    function showNotification(text,fixed) {

        if(fixed)
            osd_notify.timerEnabled=false

        osd_notify.topMargin=100

        osd_notify.text=text
        osd_notify.show();
    }

    function onSyncClicked(){
        loadingPage.operation="Refreshing Contacts"
        appWindow.pageStack.push(loadingPage);
        refreshContacts();
    }

    function onRefreshSuccess(){
        appWindow.pageStack.pop();
    }

    function onRefreshFail(){
        appWindow.pageStack.pop();
    }

    function setIndicatorState(indicatorState){

        var showPoints = [waChat, waContacts]

       // waChat.indicator_state=indicatorState

        for(var p in showPoints){
            showPoints[p].indicator_state= indicatorState
        }

    }

    function pushContacts(contacts){
        waChat.setContacts(contacts);
        waContacts.pushContacts(contacts)
    }
    function newMessage(msg_data){waContacts.newMessage(msg_data)}
    function forceRegistration(cc_val){regPage.cc_val=cc_val ;appWindow.pageStack.push(regPage)}
    function updateMessageStatus(msgKey,status){waContacts.updateMessageStatus(msgKey,status)}

    function messagesReady(messages)
    {
        waContacts.addMessage(messages.user_id, messages.data)
    }

    function onLastSeenUpdated(user_id,seconds){
        waContacts.onUnavailable(user_id,seconds);
    }

    function onAvailable(user_id){
        waContacts.onAvailable(user_id);
    }

    function onUnavailable(user_id){
        waContacts.onUnavailable(user_id);
    }

    function onTyping(user_id){
        waContacts.onTyping(user_id);
    }

    function onMessageSent(message){
        waContacts.onMessageSent(message);
        waChat.onMessageSent(message.id)
    }

    function onMessageDelivered(message){
        waContacts.onMessageDelivered(message);
        waChat.onMessageDelivered(message.id)
    }

    function onPaused(user_id){
        waContacts.onPaused(user_id);
    }

    function onRefreshing(){
        osd_notify.text="Refreshing";
        osd_notify.show();
    }


    function regSuccess()
    {
        console.log("REGISTRATION DONE!");
    }
    function regFail(reason)
    {
        console.log("REGISTRATION FAILED BECAUSE "+reason)
    }

    /*****************************************/


    Registration{
        id:regPage
        onSendReg:
        {
            loadingPage.operation="Sending SMS to "+cc+number
            sendRegRequest(number,cc);
            appWindow.pageStack.push(loadingPage)
        }
    }


    LoadingPage{
        id:loadingPage
    }


    Page {
        id: mainPage;
      // anchors.top: status_indicator.bottom

        tools: mainTools

        TabGroup {
            id: tabGroup
            currentTab: waChat
          //  platformAnimated: true

            //Page
            Chats{
                id:waChat
                height: parent.height
                Component.onCompleted:  waChat.clicked.connect(waContacts.openChatWindow)
            }
            //Page
            Contacts{
                id: waContacts
                height: parent.height

                Component.onCompleted: {
                    //connecting signals
                    waContacts.conversationUpdated.connect(waChat.updateConversation)
                    waContacts.sendMessage.connect(appWindow.sendMessage);
                    waContacts.sendTyping.connect(appWindow.sendTyping);
                    waContacts.sendPaused.connect(appWindow.sendPaused);
                }
            }
        }



        ToolBarLayout {

            id:mainTools

            ToolIcon{
                iconSource: "pics/wazapp48.png"
                opacity: 0.5
               platformStyle: ToolButtonStyle{inverted: stealth || theme.inverted}

            }

            ButtonRow {
                style: TabButtonStyle { inverted:stealth || theme.inverted }

                TabButton {
                    platformStyle: TabButtonStyle{inverted: stealth || theme.inverted}
                    text:"Chats"
                    //iconSource: "../images/icon-m-toolbar-home.png"
                    tab: waChat
                }
                TabButton {
                     platformStyle: TabButtonStyle{inverted: stealth || theme.inverted}
                    text:"Contacts"
                    // iconSource: "../images/icon-m-toolbar-list.png"
                    tab: waContacts
                }
            }

            ToolIcon {
                platformStyle: ToolButtonStyle{inverted: stealth || theme.inverted}
                id:toolbar_menu_item
                platformIconId: "toolbar-view-menu"
                onClicked: (waMenu.status === DialogStatus.Closed) ? waMenu.open() : waMenu.close()
            }
        }



    }



    WAMenu {
        id: waMenu
        //onSyncClicked: {console.log("GOTCHA");refreshContacts()}
        Component.onCompleted: {
                waMenu.syncClicked.connect(onSyncClicked)

                }

        onAboutClicked: {
            aboutDialog.open();
        }

    }

    QueryDialog {
        id: quitConfirm
        titleText: qsTrId("Confirm Quit")
        message: "Are you sure you want to quit Whatsapp?"
        acceptButtonText: qsTrId("Yes")
        rejectButtonText: qsTrId("No")
        onAccepted: quit();
    }
    Dialog{
       // anchors.fill: parent
        property string phone_number;
        id:aboutDialog
        width:parent.width
       // Component.onCompleted: {regconfirm.accepted.connect(_sendReg)}



        title:Text{
            color:"white"
            text:"About Wazapp"
            font.pixelSize: 20
        }

        content: Text{
            color:"white"
            width:parent.width
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            font.pixelSize: 22
               // horizontalAlignment: Text.AlignHCenter
            text:"Version 0.1.8\n\n This is a beta version. You are trying it at your own risk. Please report any bugs to tarek@wazapp.im "
        }

        buttons:ButtonRow {
            style: ButtonStyle { }
            anchors.horizontalCenter: parent.horizontalCenter


            Button{
                text:"Close"
                onClicked: aboutDialog.close();
            }


        }

    }

}
