import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

PageStackWindow {
    id: appWindow

    Component.onCompleted: {
        if(initType == 2)
        {
            editPage.phoneNumber=currPhoneNumber;
            editPage.pushName = currPushName;
        }
    }

    InfoBanner {
        id:osd_notify
        topMargin: 10
       // iconSource: "system_banner_thumbnail.png"
    }

    initialPage: initType == 2? editPage:regPage


    Connections {
            target:actor
            onStatusUpdated:{
               regLoading.state = status;
            }
            onRegistrationFailed:{
                //failPage.reason = reason;
               // appWindow.pageStack.push(failPage);
                showNotification(reason);
                regPage.showAlternatives();
                appWindow.pageStack.pop(null);

            }
            onRegistrationSuccess:{
                console.log("CAUGHT SUCCESS");
                editPage.status="Offline"
                console.log("REG SUCCESS "+phoneNumber);
                editPage.phoneNumber=phoneNumber
                editPage.pushName = phoneNumber
                //appWindow.pageStack.pop(null);
                appWindow.pageStack.push(editPage);
                showNotification("Successfully Registered!\n Close me and relaunch Wazapp to login");
            }

            onVoiceCodeRequested:{
                appWindow.pageStack.push(codeEntry);
                showNotification("Code was requested successfully. You should receive a call now.");
            }
        }


    function showNotification(text,fixed) {

        if(fixed)
            osd_notify.timerEnabled=false

        osd_notify.topMargin=100

        osd_notify.text=text
        osd_notify.show();
    }


    VoiceRegistration{
        id:voiceRegPage
        onSaveAccount: {
            regPage.allFail = true
             appWindow.pageStack.push(regVoiceLoading)
            regVoiceLoading.startTimer(10000)
             actor.voiceCodeRequest(cc_val,number_val);
        }
    }


    Registration {
        id:regPage
        allFail: false
        onSaveAccount: {

            appWindow.pageStack.push(regLoading)
            regLoading.startTimer(30000);
            voiceRegPage.cc = cc_val;
            voiceRegPage.number = number_val;
             actor.registerAccount(cc_val,number_val)
             //call save function here on actor
            }
    }

    EditPage{
        id:editPage
    }

    FailPage{
        id:failPage
    }


    CodeEntry{
        id:codeEntry
        onSaveAccount: {
            appWindow.pageStack.push(codeEntryLoading);
            codeEntryLoading.startTimer(10000)
            actor.regRequest(code)
        }
    }

    LoadingPage{
        id:codeEntryLoading

        state: "reg_a"
        buttonOneText: "Cancel"

        onButtonOneClicked: console.log("cancel clicked")


        states: [
            State {
                name: "reg_a"
                PropertyChanges {
                    target: codeEntryLoading
                    operation:"Verifying your account"
                }
            }
        ]
    }

    LoadingPage{
        id:regVoiceLoading;
        state: "reg_a"
        buttonOneText: "Enter code manually"

        onButtonOneClicked: console.log("manual code entry clicked")

        states: [
            State {
                name: "reg_a"
                PropertyChanges {
                    target: regVoiceLoading
                    operation:"Sending Voice Registration Request"
                }
            }
        ]
    }

    LoadingPage{
        id:regLoading;
        state: "reg_a"
        buttonOneText: "Enter code manually"
        buttonTwoText: "Use voice request"

        onButtonOneClicked: {
            console.log("manual code entry clicked")
            actor.stopCodeRequest();
            appWindow.pageStack.push(codeEntry)
        }

        onButtonTwoClicked: {
            console.log("voice entry clicked")
            actor.stopCodeRequest();
            regPage.allFail = true

            appWindow.pageStack.push(voiceRegPage);
        }


        states: [
            State {
                name: "reg_a"
                PropertyChanges {
                    target: regLoading
                    operation:"Sending Registration Request"

                }
            },
            State {
                name: "reg_b"
                PropertyChanges {
                    target: regLoading
                    operation: "Waiting for SMS"

                }
            },
            State {
                name: "reg_c"
                PropertyChanges {
                    target: regLoading
                    operation:"Got the SMS"

                }
            },
            State {
                name: "reg_d"
                PropertyChanges {
                    target: regLoading
                    operation:"Authenticating"

                }
            },

            State {
                name: "reg_e"
                PropertyChanges {
                    target: regLoading
                    operation:"Success"

                }
            }

        ]
    }

    MainPage {
        id: mainPage
    }

    ToolBarLayout {
        id: commonTools
        visible: false
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: Qt.quit()
        }
    }

    ToolBarLayout {
        id: editTools
        visible: false
        /*ToolButton {
            text: qsTrId("Save")
            //enabled: mainPage.checkFilled()
            onClicked: mainPage.saveAccount()
        }
        ToolButton {
            text: qsTrId("Cancel")
            onClicked: Qt.quit()
        }*/
        ToolIcon {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (myMenu.status == DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }
    }

    Menu {
        id: myMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem { text: qsTrId("Delete Account"); onClicked: delconfirm.open() }
        }
    }

    QueryDialog {
        id: delconfirm
        titleText: qsTrId("Confirm Delete")
        message: qsTrId("Delete account?")
        acceptButtonText: qsTrId("Delete")
        rejectButtonText: qsTrId("Cancel")
        onAccepted: actor.deleteAccount()
    }
}
